@@ -126,6 +126,4 @@ def copy_fig(fig):
     buf.seek(0)
     # Loading the figure in a new figure
     fig_dock = pickle.load(buf)
-    for i, ax in enumerate(fig_dock.axes):
-        axes = ax
     return fig_dock
