@@ -7,11 +7,13 @@ from logging.handlers import QueueListener
 from pytest import param
 
 
-def save_gif(queue, widget, main_widget, gif, plot_input, data_selection, is_3D):
+def save_gif(
+    queue, widget, main_widget, gif, plot_input, data_selection, is_3D, suptitle_ref
+):
 
     animated_axis = plot_input.pop(0)
 
-    param_dict = main_widget.plot_arg_dict.copy()
+    param_dict = widget.param_dict.copy()
 
     param_dict["save_path"] = gif
 
@@ -23,6 +25,8 @@ def save_gif(queue, widget, main_widget, gif, plot_input, data_selection, is_3D)
     ] = widget.get_plot_info()
 
     if "type_plot" in param_dict and param_dict["type_plot"] == "quiver":
+        param_dict = main_widget.plot_arg_dict.copy()
+        param_dict["save_path"] = gif
         if widget.w_vect_selector.get_component_selected() != "all":
             component_list = [widget.w_vect_selector.get_component_selected()]
         else:
@@ -54,16 +58,19 @@ def save_gif(queue, widget, main_widget, gif, plot_input, data_selection, is_3D)
         )
 
     else:
+
+        param_dict["unit"] = output_range["unit"]
+
         if "component_list" in param_dict:
             param_dict.pop("component_list")
 
         if is_3D:
             widget.data.plot_3D_Data_Animated(
-                animated_axis, *plot_input, *data_selection, **param_dict
+                animated_axis, suptitle_ref, *plot_input, **param_dict
             )
         else:
             widget.data.plot_2D_Data_Animated(
-                animated_axis, *plot_input, *data_selection, **param_dict
+                animated_axis, suptitle_ref, *plot_input, **param_dict
             )
     queue.put("gif generated")
 
@@ -81,6 +88,7 @@ class SaveGifWorker(QObject):
         plot_input=list(),
         data_selection=list(),
         is_3D=False,
+        suptitle_ref="",
     ):
         super().__init__()
         self.widget = widget
@@ -89,6 +97,7 @@ class SaveGifWorker(QObject):
         self.plot_input = plot_input
         self.data_selection = data_selection
         self.is_3D = is_3D
+        self.suptitle_ref = suptitle_ref
         self.queue = multiprocessing.Queue()
         # used to check if the is finished
         self.queue_handler = GifHandler(parent=self)
@@ -108,6 +117,7 @@ class SaveGifWorker(QObject):
                 self.plot_input,
                 self.data_selection,
                 self.is_3D,
+                self.suptitle_ref,
             ),
         )
         self.p.daemon = True
