@@ -18,25 +18,25 @@ from SciDataTool.GUI.Resources import SDT_rc
 class Ui_WSliceOperator(object):
     def setupUi(self, WSliceOperator):
         if not WSliceOperator.objectName():
-            WSliceOperator.setObjectName(u"WSliceOperator")
-        WSliceOperator.resize(375, 166)
+            WSliceOperator.setObjectName("WSliceOperator")
+        WSliceOperator.resize(375, 133)
         self.gridLayout = QGridLayout(WSliceOperator)
-        self.gridLayout.setObjectName(u"gridLayout")
+        self.gridLayout.setObjectName("gridLayout")
         self.b_action = QPushButton(WSliceOperator)
-        self.b_action.setObjectName(u"b_action")
+        self.b_action.setObjectName("b_action")
         sizePolicy = QSizePolicy(QSizePolicy.Preferred, QSizePolicy.Fixed)
         sizePolicy.setHorizontalStretch(0)
         sizePolicy.setVerticalStretch(0)
         sizePolicy.setHeightForWidth(self.b_action.sizePolicy().hasHeightForWidth())
         self.b_action.setSizePolicy(sizePolicy)
-        self.b_action.setMinimumSize(QSize(0, 20))
+        self.b_action.setMinimumSize(QSize(0, 30))
 
         self.gridLayout.addWidget(self.b_action, 2, 0, 1, 1)
 
         self.horizontalLayout_2 = QHBoxLayout()
-        self.horizontalLayout_2.setObjectName(u"horizontalLayout_2")
+        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
         self.lf_value = FloatEdit(WSliceOperator)
-        self.lf_value.setObjectName(u"lf_value")
+        self.lf_value.setObjectName("lf_value")
         sizePolicy1 = QSizePolicy(QSizePolicy.Preferred, QSizePolicy.Fixed)
         sizePolicy1.setHorizontalStretch(70)
         sizePolicy1.setVerticalStretch(0)
@@ -48,12 +48,12 @@ class Ui_WSliceOperator(object):
         self.horizontalLayout_2.addWidget(self.lf_value)
 
         self.in_unit = QLabel(WSliceOperator)
-        self.in_unit.setObjectName(u"in_unit")
+        self.in_unit.setObjectName("in_unit")
 
         self.horizontalLayout_2.addWidget(self.in_unit)
 
         self.slider = QSlider(WSliceOperator)
-        self.slider.setObjectName(u"slider")
+        self.slider.setObjectName("slider")
         sizePolicy2 = QSizePolicy(QSizePolicy.Expanding, QSizePolicy.Fixed)
         sizePolicy2.setHorizontalStretch(0)
         sizePolicy2.setVerticalStretch(0)
@@ -65,7 +65,7 @@ class Ui_WSliceOperator(object):
         self.horizontalLayout_2.addWidget(self.slider)
 
         self.b_animate = ButtonLabel(WSliceOperator)
-        self.b_animate.setObjectName(u"b_animate")
+        self.b_animate.setObjectName("b_animate")
         sizePolicy3 = QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed)
         sizePolicy3.setHorizontalStretch(0)
         sizePolicy3.setVerticalStretch(0)
@@ -81,9 +81,9 @@ class Ui_WSliceOperator(object):
         self.gridLayout.addLayout(self.horizontalLayout_2, 1, 0, 1, 1)
 
         self.horizontalLayout = QHBoxLayout()
-        self.horizontalLayout.setObjectName(u"horizontalLayout")
+        self.horizontalLayout.setObjectName("horizontalLayout")
         self.in_name = QLabel(WSliceOperator)
-        self.in_name.setObjectName(u"in_name")
+        self.in_name.setObjectName("in_name")
         sizePolicy.setHeightForWidth(self.in_name.sizePolicy().hasHeightForWidth())
         self.in_name.setSizePolicy(sizePolicy)
         self.in_name.setMinimumSize(QSize(0, 20))
@@ -99,7 +99,7 @@ class Ui_WSliceOperator(object):
         self.c_operation.addItem("")
         self.c_operation.addItem("")
         self.c_operation.addItem("")
-        self.c_operation.setObjectName(u"c_operation")
+        self.c_operation.setObjectName("c_operation")
         sizePolicy.setHeightForWidth(self.c_operation.sizePolicy().hasHeightForWidth())
         self.c_operation.setSizePolicy(sizePolicy)
         self.c_operation.setMinimumSize(QSize(0, 20))
@@ -109,7 +109,7 @@ class Ui_WSliceOperator(object):
         self.gridLayout.addLayout(self.horizontalLayout, 0, 0, 1, 1)
 
         self.l_loading = QLabel(WSliceOperator)
-        self.l_loading.setObjectName(u"l_loading")
+        self.l_loading.setObjectName("l_loading")
         self.l_loading.setEnabled(True)
 
         self.gridLayout.addWidget(self.l_loading, 3, 0, 1, 1)
@@ -122,46 +122,46 @@ class Ui_WSliceOperator(object):
 
     def retranslateUi(self, WSliceOperator):
         WSliceOperator.setWindowTitle(
-            QCoreApplication.translate("WSliceOperator", u"WSliceOperator", None)
+            QCoreApplication.translate("WSliceOperator", "WSliceOperator", None)
         )
         self.b_action.setText(
-            QCoreApplication.translate("WSliceOperator", u"Overlay", None)
+            QCoreApplication.translate("WSliceOperator", "Overlay", None)
         )
         self.lf_value.setText(
-            QCoreApplication.translate("WSliceOperator", u"0.314", None)
+            QCoreApplication.translate("WSliceOperator", "0.314", None)
         )
-        self.in_unit.setText(QCoreApplication.translate("WSliceOperator", u"[m]", None))
+        self.in_unit.setText(QCoreApplication.translate("WSliceOperator", "[m]", None))
         self.b_animate.setText("")
         self.in_name.setText(
-            QCoreApplication.translate("WSliceOperator", u"angle", None)
+            QCoreApplication.translate("WSliceOperator", "angle", None)
         )
         self.c_operation.setItemText(
-            0, QCoreApplication.translate("WSliceOperator", u"slice", None)
+            0, QCoreApplication.translate("WSliceOperator", "slice", None)
         )
         self.c_operation.setItemText(
-            1, QCoreApplication.translate("WSliceOperator", u"slice (fft)", None)
+            1, QCoreApplication.translate("WSliceOperator", "slice (fft)", None)
         )
         self.c_operation.setItemText(
-            2, QCoreApplication.translate("WSliceOperator", u"rms", None)
+            2, QCoreApplication.translate("WSliceOperator", "rms", None)
         )
         self.c_operation.setItemText(
-            3, QCoreApplication.translate("WSliceOperator", u"rss", None)
+            3, QCoreApplication.translate("WSliceOperator", "rss", None)
         )
         self.c_operation.setItemText(
-            4, QCoreApplication.translate("WSliceOperator", u"sum", None)
+            4, QCoreApplication.translate("WSliceOperator", "sum", None)
         )
         self.c_operation.setItemText(
-            5, QCoreApplication.translate("WSliceOperator", u"mean", None)
+            5, QCoreApplication.translate("WSliceOperator", "mean", None)
         )
         self.c_operation.setItemText(
-            6, QCoreApplication.translate("WSliceOperator", u"integrate", None)
+            6, QCoreApplication.translate("WSliceOperator", "integrate", None)
         )
         self.c_operation.setItemText(
-            7, QCoreApplication.translate("WSliceOperator", u"overlay/filter", None)
+            7, QCoreApplication.translate("WSliceOperator", "overlay/filter", None)
         )
 
         self.l_loading.setText(
-            QCoreApplication.translate("WSliceOperator", u"Generating...", None)
+            QCoreApplication.translate("WSliceOperator", "Generating...", None)
         )
 
     # retranslateUi
